@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 1998-2000 Free Software Foundation
+ * Copyright (C) 1998-2001 Free Software Foundation
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU General Public
@@ -83,6 +83,7 @@ static GtkWidget *pb = NULL;
 
 guint timeout_handler_id;
 gboolean double_clicked;
+gboolean druid_already_launched = FALSE;
 
 static GtkWidget *progressDialog=NULL;
 static GtkWidget *sync_label,*overall_progress_bar,*conduit_progress_bar, *message_area;
@@ -112,7 +113,7 @@ static void pilot_execute_program (const gchar *);
 static void 
 gpilotd_connect_cb (GnomePilotClient* client, 
 		    const gchar *id,
-		    const GNOME_Pilot_PilotUser *user,
+		    const GNOME_Pilot_UserInfo *user,
 		    gpointer unused)
 {
 	GdkColormap *colormap;
@@ -145,7 +146,7 @@ gpilotd_connect_cb (GnomePilotClient* client,
 				gtk_text_get_length (GTK_TEXT (message_area)));
 	}
 
-	gtk_widget_set_sensitive (cancel_button,FALSE);
+	gtk_widget_set_sensitive (cancel_button, FALSE);
 	buf=g_strdup_printf (_("%s Synchronizing"),id);
 	gtk_label_set_text (GTK_LABEL (sync_label),buf);
 	g_free (buf);
@@ -397,26 +398,18 @@ pilot_draw (GtkWidget *pixmap)
 static int 
 timeout (gpointer data) 
 {
-	switch (curstate) {
-		
-	case INITIALISING: {
+	if (curstate == INITIALISING) {
 		g_message ("state = INITIALISING");
 		pilot_draw (GTK_WIDGET (data));
 		
 		if (gnome_pilot_client_connect_to_daemon (gpc) == GPILOTD_OK) {
 			curstate = CONNECTING_TO_DAEMON;
 			pilot_draw (GTK_WIDGET (data));
-		} else {
-			/* timeout_handler_id = gtk_timeout_add (3000,timeout,data); */
-		}
-		return TRUE;
-	} break;
+		} 
+	}
 	
-	case CONNECTING_TO_DAEMON: {
+	if (curstate == CONNECTING_TO_DAEMON) {
 		g_message ("state = CONNECTING_TO_DAEMON");
-
-                gtk_timeout_remove (timeout_handler_id); 
-		timeout_handler_id = gtk_timeout_add (5000,timeout,pixmap);
 		
 		if (properties.pilot_ids) {
 			GList *tmp =properties.pilot_ids;
@@ -426,38 +419,46 @@ timeout (gpointer data)
 			} 
 			g_list_free (properties.pilot_ids);
 		}
+
 		properties.pilot_ids = get_pilot_ids_from_gpilotd ();
+
 		if (properties.pilot_ids==NULL){
-			applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Not connected. Restart daemon to reconnect"));
-			pilot_execute_program (GPILOTD_DRUID);
+			applet_widget_set_tooltip (APPLET_WIDGET (applet),
+						   _("Not connected. Restart daemon to reconnect"));
+			if (druid_already_launched == FALSE) {
+				druid_already_launched = TRUE;
+				pilot_execute_program (GPILOTD_DRUID);
+			}
+
 			curstate=INITIALISING;
 			pilot_draw (GTK_WIDGET (data));
 			/* FIXME: add gpilot_monitor_state_change () */
-			return FALSE;
+		} else {
+			gnome_pilot_client_monitor_on_all_pilots (gpc);
+			
+			gnome_pilot_client_notify_on (gpc,GNOME_Pilot_NOTIFY_CONNECT);
+			gnome_pilot_client_notify_on (gpc,GNOME_Pilot_NOTIFY_CONDUIT);
+			gnome_pilot_client_notify_on (gpc,GNOME_Pilot_NOTIFY_DISCONNECT);
+			
+			applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Ready to synchronize"));
+			
+			curstate = WAITING;
+			pilot_draw (GTK_WIDGET (data));    
 		}
-		gnome_pilot_client_monitor_on_all_pilots (gpc);
-		
-		gnome_pilot_client_notify_on (gpc,GNOME_Pilot_NOTIFY_CONNECT);
-		gnome_pilot_client_notify_on (gpc,GNOME_Pilot_NOTIFY_CONDUIT);
-		gnome_pilot_client_notify_on (gpc,GNOME_Pilot_NOTIFY_DISCONNECT);
-		
-		applet_widget_set_tooltip (APPLET_WIDGET (applet),_("Ready to synchronize"));
-		
-		curstate = WAITING;
-		pilot_draw (GTK_WIDGET (data));    
-	} break;
+	} 
+
+	switch (curstate) {
 	case WAITING:
+		/* this will happen once a sec */
 		if (gnome_pilot_client_noop (gpc) == GPILOTD_ERR_NOT_CONNECTED) {
 			curstate = INITIALISING;
-			gtk_timeout_remove (timeout_handler_id); 
-			timeout_handler_id = gtk_timeout_add (1000,timeout,pixmap);
 		}
 		break;
 	case SYNCING: 
-	break;
-	default: g_error ("curstate == default ?!"); break;
+		break;
 	}
-	
+
+	/* Keep timeout calls coming */
 	return TRUE;
 }
 
@@ -832,7 +833,7 @@ static void
 lastlog_dialog (GtkWidget *widget, gpointer data)
 {
 	if (progressDialog != NULL) {
-		gtk_label_set_text (GTK_LABEL (sync_label),"Last Sync Log");
+		/* gtk_label_set_text (GTK_LABEL (sync_label),"Last Sync Log"); */
 		gtk_widget_set_sensitive (cancel_button,TRUE);
 		gtk_widget_show_all (progressDialog);
 	} else {
@@ -905,12 +906,12 @@ dnd_drop_internal (GtkWidget        *widget,
 				  g_message ("installing textfile as Memo (not implemented)");
 				  }
 				*/
-				g_message (_("installing \"%s\""), ptr);
+				g_message (_("installing \"%s\" to \"%s\""), ptr, pilot_id);
 				if (pilot_id) {
 					gnome_pilot_client_install_file (gpc,pilot_id,
 									ptr,
 									GNOME_Pilot_PERSISTENT,0,&file_handle);
-				}
+				} 
 			}
 		}
 #if WITH_VFS
@@ -930,15 +931,15 @@ static void
 about_cb (AppletWidget *widget, gpointer data)
 {
 	GtkWidget *about;
-	const gchar *authors[] = {"Vadim Strizhevsky, vadim@optonline.net"," Eskil Heyn Olsen, eskil@eazel.com",NULL};
+	const gchar *authors[] = {"Vadim Strizhevsky, vadim@optonline.net"," Eskil Heyn Olsen, eskil@eskil.dk",NULL};
 	gchar version[] = VERSION;
 
-	about = gnome_about_new (_("Gnome Pilot Applet"), 
+	about = gnome_about_new (_("gnome-pilot applet"), 
 				version,
 				_("(C) 2000 Free Software Foundation "),
 				(const gchar**)authors,
 				_("A dnd and gui monitor for gpilotd.\n"
-				  "Visit Website at http://www.gnome.org/gnome-pilot"),
+				  "Visit Website at http://eskil.org/gnome-pilot"),
 				NULL);
 	gtk_widget_show (about);
 
@@ -1083,15 +1084,12 @@ create_pilot_widget (GtkWidget *window)
 					      _("Last sync log..."),
 					      GTK_SIGNAL_FUNC (lastlog_dialog),
 					      NULL);	
-#if 0 
-        /* FIXME: remove undef when the new capplet is checked in */
 	applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 					      "conduitprops",
 					      GNOME_STOCK_MENU_PROP,
 					      _("Conduit Settings..."),
 					      GTK_SIGNAL_FUNC (pilot_link_dialog),
 					      GINT_TO_POINTER (1));	
-#endif
 	applet_widget_register_stock_callback (APPLET_WIDGET (applet),
 					      "pilotlinkprops",
 					      GNOME_STOCK_MENU_PROP,
