@@ -503,15 +503,15 @@ gpilotd_corba_get_system_info(GNOME_Pilot_Daemon obj,
 static CORBA_unsigned_long
 gpilotd_corba_set_user_info(GNOME_Pilot_Daemon obj,
 			    const GNOME_Pilot_Client cb,
-			    GNOME_Pilot_PilotUser *user,
+			    GNOME_Pilot_UserInfo *user,
 			    const CORBA_char *cradle, 
 			    const CORBA_boolean continue_sync,
 			    const GNOME_Pilot_Survival survival,
 			    const CORBA_unsigned_long timeout, 
 			    CORBA_Environment *ev) 
 {
-	GPilotRequest req;
 	gchar *client_id;
+	int result;
 
 	GET_AND_CHECK_CLIENT_ID(client_id,cb,0);
 
@@ -522,25 +522,23 @@ gpilotd_corba_set_user_info(GNOME_Pilot_Daemon obj,
 	LOG("corba:               user    = %s)",user->username);
 	/*LOG("corba:               password= %s)",user->password);*/
 	/* FIXME: check for cradle existance, throw exn if not */
-	req.type = GREQ_SET_USERINFO;
-	req.pilot_id = 0;
-	req.timeout = survival==GNOME_Pilot_PERSISTENT?0:timeout;
-	req.cradle = g_strdup(cradle);
-	req.client_id = g_strdup(client_id);
-	req.parameters.set_userinfo.password = NULL;
-	req.parameters.set_userinfo.user_id = g_strdup(user->username);
-	req.parameters.set_userinfo.pilot_id = user->userID;
-	req.parameters.set_userinfo.continue_sync = continue_sync;
+
+	result = gpc_queue_store_set_userinfo_request (survival==GNOME_Pilot_PERSISTENT?0:timeout,
+						       cradle,
+						       client_id,
+						       user->username,
+						       user->userID,
+						       continue_sync);
 
 	g_free(client_id);
 
-	return gpc_queue_store_request(req);
+	return result;
 }
 
 #if 0
 static CORBA_unsigned_long
 gpilotd_corba_set_user_info_if_not_set(GNOME_Pilot_Daemon obj,
-				       GNOME_Pilot_PilotUser *user,
+				       GNOME_Pilot_UserInfo *user,
 				       const GNOME_Pilot_Client cb,
 				       const CORBA_char *cradle, 
 				       const GNOME_Pilot_Survival survival,
@@ -1485,7 +1483,7 @@ void
 orbed_notify_connect(const gchar *pilot_id, 
 		     struct PilotUser user_info) 
 {
-	GNOME_Pilot_PilotUser user_info_orbed;
+	GNOME_Pilot_UserInfo user_info_orbed;
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 
@@ -1618,7 +1616,7 @@ void
 orbed_notify_userinfo(struct PilotUser user_info,
 		      GPilotRequest **req) 
 {
-	GNOME_Pilot_PilotUser user;
+	GNOME_Pilot_UserInfo user;
 	GNOME_Pilot_Client cb;
 
 	g_return_if_fail(req!=NULL);
@@ -1773,6 +1771,9 @@ orbed_notify_conduit_error(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1801,6 +1802,9 @@ orbed_notify_conduit_message(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1826,6 +1830,9 @@ orbed_notify_daemon_message(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1850,6 +1857,9 @@ orbed_notify_daemon_error (gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (message);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1875,6 +1885,9 @@ orbed_notify_conduit_progress(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+	g_assert (conduit);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -1901,6 +1914,8 @@ orbed_notify_overall_progress(gchar *pilot_id,
 	GPilotd_notify_foreach_carrier carrier;
 	GPilotd_Orb_Pilot_Notifications *notifications;
 	
+	g_assert (pilot_id);
+
 	if((notifications = g_hash_table_lookup(orb_context->notifications,pilot_id))==NULL) {
 		return;
 	}
@@ -2060,7 +2075,7 @@ void gpilotd_corba_init(int *argc,
 	acc = PortableServer_POA_servant_to_reference(the_poa, &daemon_servant, &ev);
 	g_return_if_fail(ev._major == CORBA_NO_EXCEPTION);
 
-	g_message ("Activating server");
+	g_message ("Activating CORBA server");
 #ifdef USING_OAF
 	result = oaf_active_server_register (
               "OAFIID:gpilotd:a40c417b-21db-4959-a58e-40096a0daf09",
